// app/actions/containerActions.ts
import Docker from 'dockerode';

const docker = new Docker({ socketPath: '/var/run/docker.sock' });

// 批量创建容器
export async function createContainers(count: number, baseName: string, startingPorts: [number, number]) {
    const [vncStart, sshStart] = startingPorts;
    const promises = [];

    for (let i = 0; i < count; i++) {
        const containerName = `${baseName}-${i}`;
        const vncPort = vncStart + i;
        const sshPort = sshStart + i;

        const container = docker.createContainer({
            Image: 'ubuntu-xfce-vnc-ssh', // 使用你的镜像
            name: containerName,
            ExposedPorts: {
                '5900/tcp': {}, // VNC 默认端口
                '22/tcp': {},   // SSH/SFTP 默认端口
            },
            HostConfig: {
                PortBindings: {
                    '5900/tcp': [{ HostPort: vncPort.toString() }],
                    '22/tcp': [{ HostPort: sshPort.toString() }],
                },
            },
        });

        promises.push(container);
    }

    return Promise.all(promises);
}

// 关闭容器
export async function stopContainer(containerName: string) {
    const container = docker.getContainer(containerName);
    await container.stop();
    return { message: `Container ${containerName} stopped successfully.` };
}

// 删除容器
export async function removeContainer(containerName: string) {
    const container = docker.getContainer(containerName);
    await container.remove();
    return { message: `Container ${containerName} removed successfully.` };
}

// 获取容器信息
export async function getContainerInfo(containerName: string) {
    const container = docker.getContainer(containerName);
    const info = await container.inspect();
    return {
        containerName: info.Name,
        state: info.State.Status,
        ports: info.NetworkSettings.Ports,
    };
}

// 启动容器
export async function startContainer(containerName: string) {
    const container = docker.getContainer(containerName);
    await container.start();
    return { message: `Container ${containerName} started successfully.` };
}
